Contributors
============

* Aaron Egaas <me@aaronegaas.com>
* Aditya Bhasin <conlini@gmail.com>
* Alexis Metaireau <alexis@mozilla.com>
* Andy McKay <amckay@mozilla.com>
* Aymeric Faivre <miho@miho-stories.com>
* Ayush Sharma <ayush.aceit@gmail.com>
* Balthazar Rouberol <br@imap.cc>
* Chirag B. Jadwani <chirag.jadwani@gmail.com>
* Clément Villain <choclatefr@gmail.com>
* Dan Phrawzty <phrawzty+github@gmail.com>
* David Larlet <david@larlet.fr>
* Enguerran <engcolson@gmail.com>
* Eric Bréhault <ebrehault@gmail.com>
* Éric Lemoine <eric.lemoine@gmail.com>
* Ethan Glasser-Camp <ethan@betacantrips.com>
* Fil <fil@rezo.net>
* FooBarQuaxx
* Greeshma <greeshmabalabadra@gmail.com>
* Hiromipaw <silvia@nopressure.co.uk>
* Jelmer van der Ploeg <jelmer@woovar.com>
* John Giannelos <johngiannelos@gmail.com>
* Julien Bouquillon <contact@revolunet.com>
* Lavish Aggarwal <lucky.lavish@gmail.com>
* Maksym Shalenyi <supamaxy@gmail.com>
* Masataka Takeuchi <masataka.takeuchi@l-is-b.com>
* Mathieu Agopian <mathieu@agopian.info>
* Mathieu Leplatre <mathieu@mozilla.com>
* Maxime Varnier <marmax@gmail.com>
* Michiel de Jong <michiel@unhosted.org>
* Nicolas Hoizey <nicolas@hoizey.com>
* Nicolas Perriault <nperriault@mozilla.com>
* Niraj <https://github.com/niraj8>
* Rektide <rektide@voodoowarez.com>
* Rodolphe Quiédeville <rodolphe@quiedeville.org>
* Rémy Hubscher <rhubscher@mozilla.com>
* Shweta Oak <oakshweta11@gmail.com>
* Sofia Utsch <sofia.utsch@gmail.com>
* SwhGo_oN
* Tarek Ziade <tarek@mozilla.com>
* Taylor Zane Glaeser <tzglaeser@gmail.com>
* Wil Clouser <wclouser@mozilla.com>
* Yann Klis <yann.klis@gmail.com>
